==> cbpl-unicom-1.0.0-20230209.101709-1-sources.jar: com/elitesland/cbpl/unicom/config/UnicomProperties.java <==
package com.elitesland.cbpl.unicom.config;

import com.elitesland.cbpl.unicom.domain.InvokeMode;
import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.bind.BindResult;
import org.springframework.boot.context.properties.bind.Binder;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.util.Set;

/**
 * @author eric.hao
 * @since 2022/09/14
 */
@Data
@Configuration
@ConfigurationProperties(prefix = UnicomProperties.UNICOM_PREFIX)
public class UnicomProperties {

    public static final String UNICOM_PREFIX = "cbpl.unicom";

    /**
     * 扫描路径
     */
    private String basePackage;

    /**
     * 调用方式
     */
    private InvokeModeCfg invokeMode;

    /**
     * 根据领域，匹配调用方式
     *
     * @param domain 领域
     * @return 调用方式
     */
    public InvokeMode invokeMode(String domain) {
        // 匹配feign调用方式的域
        if (invokeMode.getFeign().contains(domain)) {
            return InvokeMode.FEIGN;
        }
        // 匹配dubbo调用方式的域
        if (invokeMode.getDubbo().contains(domain)) {
            return InvokeMode.DUBBO;
        }
        // 默认均使用本地调用的方式
        return InvokeMode.JVM;
    }

    @Data
    static class InvokeModeCfg {
        private Set<String> jvm;
        private Set<String> dubbo;
        private Set<String> feign;
    }

    /**
     * 读取环境配置
     */
    public static UnicomProperties from(Environment environment) {
        Binder env = Binder.get(environment);
        BindResult<UnicomProperties> properties = env.bind(UNICOM_PREFIX, UnicomProperties.class);
        return properties.get();
    }
}

==> cbpl-unicom-1.0.37-20230427.031751-1-sources.jar: com/elitesland/cbpl/unicom/config/UnicomProperties.java <==
package com.elitesland.cbpl.unicom.config;

import com.elitesland.cbpl.unicom.domain.InvokeMode;
import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.bind.BindResult;
import org.springframework.boot.context.properties.bind.Binder;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.util.Set;

/**
 * @author eric.hao
 * @since 2022/09/14
 */
@Data
@Configuration
@ConfigurationProperties(prefix = UnicomProperties.UNICOM_PREFIX)
public class UnicomProperties {

    public static final String UNICOM_PREFIX = "cbpl.unicom";

    /**
     * 扫描路径
     */
    private Set<String> basePackage;

    /**
     * 调用方式
     */
    private InvokeModeCfg invokeMode;

    /**
     * 默认执行的策略
     */
    private String defaultAdapter;

    /**
     * 根据领域，匹配调用方式
     *
     * @param domain 领域
     * @return 调用方式
     */
    public InvokeMode invokeMode(String domain) {
        // 匹配feign调用方式的域
        if (invokeMode.getFeign().contains(domain)) {
            return InvokeMode.FEIGN;
        }
        // 匹配dubbo调用方式的域
        if (invokeMode.getDubbo().contains(domain)) {
            return InvokeMode.DUBBO;
        }
        // 默认均使用本地调用的方式
        return InvokeMode.JVM;
    }

    @Data
    static class InvokeModeCfg {
        private Set<String> jvm;
        private Set<String> dubbo;
        private Set<String> feign;
    }

    /**
     * 读取环境配置
     */
    public static UnicomProperties from(Environment environment) {
        Binder env = Binder.get(environment);
        BindResult<UnicomProperties> properties = env.bind(UNICOM_PREFIX, UnicomProperties.class);
        return properties.get();
    }
}
